@@ -2,8 +2,9 @@
 
 from __future__ import annotations
 
-from enum import Enum, IntEnum
+from enum import IntEnum, StrEnum
 import json
+import re
 from typing import Any
 
 
@@ -39,7 +40,7 @@ class AirzoneStages(IntEnum):
         return []
 
 
-class EcoAdapt(str, Enum):
+class EcoAdapt(StrEnum):
     """Airzone Eco-Adapt."""
 
     OFF = "off"
@@ -243,3 +244,41 @@ def json_dumps(data: Any) -> Any:
     if data is not None:
         return json.dumps(data)
     return None
+
+
+def parse_bool(data: Any) -> bool | None:
+    """Convert data to bool."""
+    if data is not None:
+        return bool(data)
+    return None
+
+
+def parse_float(data: Any) -> float | None:
+    """Convert data to float."""
+    if data is not None:
+        return float(data)
+    return None
+
+
+def parse_int(data: Any) -> int | None:
+    """Convert data to int."""
+    if data is not None:
+        return int(data)
+    return None
+
+
+def parse_str(data: Any) -> str | None:
+    """Convert data to string."""
+    if data is not None:
+        return str(data)
+    return None
+
+
+def validate_mac_address(mac_addr: str | None) -> bool:
+    """Validate MAC address."""
+    if mac_addr is None:
+        return False
+    return (
+        re.match("[0-9a-f]{2}([-:]?)[0-9a-f]{2}(\\1[0-9a-f]{2}){4}$", mac_addr.lower())
+        is not None
+    )
