@@ -12,6 +12,7 @@ API_ACS_SET_POINT: Final[str] = "acs_setpoint"
 API_ACS_TEMP: Final[str] = "acs_temp"
 API_AIR_DEMAND: Final[str] = "air_demand"
 API_ANTI_FREEZE: Final[str] = "antifreeze"
+API_BATTERY: Final[str] = "battery"
 API_COLD_ANGLE: Final[str] = "coldangle"
 API_COLD_DEMAND: Final[str] = "cold_demand"
 API_COLD_STAGE: Final[str] = "coldStage"
@@ -19,6 +20,7 @@ API_COLD_STAGES: Final[str] = "coldStages"
 API_COOL_MAX_TEMP: Final[str] = "coolmaxtemp"
 API_COOL_MIN_TEMP: Final[str] = "coolmintemp"
 API_COOL_SET_POINT: Final[str] = "coolsetpoint"
+API_COVERAGE: Final[str] = "coverage"
 API_DATA: Final[str] = "data"
 API_DEMO: Final[str] = "demo"
 API_DRIVER: Final[str] = "driver"
@@ -181,9 +183,11 @@ AZD_TEMP_MIN: Final[str] = "temp-min"
 AZD_TEMP_SET: Final[str] = "temp-set"
 AZD_TEMP_STEP: Final[str] = "temp-step"
 AZD_TEMP_UNIT: Final[str] = "temp-unit"
+AZD_THERMOSTAT_BATTERY: Final[str] = "thermostat-battery"
 AZD_THERMOSTAT_FW: Final[str] = "thermostat-fw"
 AZD_THERMOSTAT_MODEL: Final[str] = "thermostat-model"
 AZD_THERMOSTAT_RADIO: Final[str] = "thermostat-radio"
+AZD_THERMOSTAT_SIGNAL: Final[str] = "thermostat-signal"
 AZD_VERSION: Final[str] = "version"
 AZD_WEBSERVER: Final[str] = "webserver"
 AZD_WIFI_CHANNEL: Final[str] = "wifi-channel"
